@@ -131,9 +131,9 @@ class Client:
 
     def __exit__(
         self,
-        exc_type: type[BaseException] | None,
-        exc_value: BaseException | None,
-        traceback: TracebackType | None,
+        exc_type: type[BaseException] | None,  # noqa: ARG002
+        exc_value: BaseException | None,  # noqa: ARG002
+        traceback: TracebackType | None,  # noqa: ARG002
     ) -> None:
         """Safely exit the client context."""
         self.close()
@@ -168,7 +168,7 @@ class Client:
     def activate_tokens(
         self,
         survey_id: int,
-        attributes: list[str] | None = None,
+        attributes: list[int] | None = None,
     ) -> dict[str, str]:
         """Initialise the survey participant table.
 
@@ -176,12 +176,12 @@ class Client:
 
         Args:
             survey_id: ID of survey to be activated.
-            attributes: Additional fields.
+            attributes: Optional list of participant attributes numbers to be activated.
 
         Returns:
             Status message.
         """
-        return self.__session.activate_tokens(survey_id)
+        return self.__session.activate_tokens(survey_id, attributes or [])
 
     def add_language(self, survey_id: int, language: str) -> dict[str, Any]:
         """Add a survey language.
@@ -398,7 +398,7 @@ class Client:
         data = self._map_response_keys(response_data, questions)
         return self.__session.update_response(survey_id, data)
 
-    def copy_survey(self, survey_id: int, name: str) -> int:
+    def copy_survey(self, survey_id: int, name: str) -> dict[str, Any]:
         """Copy a survey.
 
         Args:
@@ -406,7 +406,7 @@ class Client:
             name: Name of the new survey.
 
         Returns:
-            ID of the new survey.
+            Dictionary of status message and the new survey ID.
         """
         return self.__session.copy_survey(survey_id, name)
 
@@ -841,7 +841,7 @@ class Client:
     def get_survey_properties(
         self,
         survey_id: int,
-        properties: list[str] | None = None,
+        properties: Sequence[str] | None = None,
     ) -> dict[str, Any]:
         """Get properties of a survey.
 
