@@ -1,5 +1,7 @@
 """Common exceptions."""
 
+from __future__ import annotations
+
 
 class ResponseMismatchError(Exception):
     """Exception raised when request and response ID don't match."""
@@ -8,7 +10,7 @@ class ResponseMismatchError(Exception):
 class LimeSurveyError(Exception):
     """Basic exception raised by LimeSurvey."""
 
-    def __init__(self, message: str) -> None:  # noqa:: ANN101
+    def __init__(self, message: str) -> None:
         """Create a generic error for the LimeSurvey RPC API.
 
         Args:
