@@ -160,9 +160,8 @@ class Session:
             raise LimeSurveyApiError(error)
 
         if response_id != request_id:
-            raise ResponseMismatchError(
-                f"Response ID {response_id} does not match request ID {request_id}",
-            )
+            msg = f"Response ID {response_id} does not match request ID {request_id}"
+            raise ResponseMismatchError(msg)
 
         return result
 
@@ -187,9 +186,9 @@ class Session:
 
     def __exit__(
         self,
-        exc_type: type[BaseException] | None,
-        exc_value: BaseException | None,
-        traceback: TracebackType | None,
+        exc_type: type[BaseException] | None,  # noqa: ARG002
+        exc_value: BaseException | None,  # noqa: ARG002
+        traceback: TracebackType | None,  # noqa: ARG002
     ) -> None:
         """Safely exit an RPC session.
 
